@@ -4,7 +4,7 @@
    poptions.h : This file is part of pstoedit
    program option handling 
 
-   Copyright (C) 1993 - 2012 Wolfgang Glunz, wglunz35_AT_pstoedit.net
+   Copyright (C) 1993 - 2018 Wolfgang Glunz, wglunz35_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -30,6 +30,8 @@
 #include I_ostream
 #include I_istream
 
+#include "miscutil.h"
+
 USESTD
 
 enum baseTypeIDs { int_ty, double_ty, bool_ty, char_ty };
@@ -93,7 +95,9 @@ public:
 	};
 	virtual ~OptionBase() { membername = 0; }
 	virtual ostream & writevalue(ostream & out) const = 0;
-	void toString(class RSString &) const;  
+#if 1
+	void toString(RSString &) const;  
+#endif
 	virtual bool copyvalue(const char *optname, const char *valuestring, unsigned int &currentarg) = 0;
 	virtual bool copyvalue_simple(const char *valuestring) = 0;
 //	virtual bool copyvalue_simple(bool boolvalue) = 0; 
@@ -121,11 +125,12 @@ template <class ValueType, class ExtractorType >
 class OptionT : public OptionBase {
 public:
 	OptionT < ValueType, ExtractorType > (bool optional_p, const char *flag_p, const char *argname_p, int propsheet_p, const char *description_p, const char * TeXhelp_p, const ValueType & initialvalue)	:
-		OptionBase(optional_p,flag_p, argname_p, propsheet_p, description_p,TeXhelp_p),
+		OptionBase(optional_p, flag_p, argname_p, propsheet_p, description_p, TeXhelp_p),
 		value(initialvalue) {
 	};
 	OptionT < ValueType, ExtractorType > (bool optional_p, const char *flag_p, const char *argname_p, int propsheet_p, const char *description_p, const char * TeXhelp_p )	:
-		OptionBase(optional_p,flag_p, argname_p, propsheet_p, description_p, TeXhelp_p) 
+		OptionBase(optional_p, flag_p, argname_p, propsheet_p, description_p, TeXhelp_p),
+        value() // use default init for value
 	{
 			//lint -esym(1401,*::value) // not initialized - we use the default ctor here
 	};
@@ -166,7 +171,7 @@ public:
 		/* return */ value = arg; 
 		//lint -esym(1539,OptionBase::propsheet)  // not assigned in op=
 		//lint -esym(1539,OptionBase::membername) // not assigned in op=
-	} //  cannot return a reference, because char*::operator= doesn't
+	} //  cannot return a reference, because char*::operator= does not
 	//lint -restore
 	bool operator !=(const ValueType & arg) const { return value != arg; }
 	bool operator ==(const ValueType & arg) const { return value == arg; }
@@ -191,14 +196,16 @@ ostream & OptionT<ValueType, ExtractorType>::writevalue(ostream & out) const {
 
 class DLLEXPORT ProgramOptions {
 public:
-	ProgramOptions() : unhandledCounter(0), optcount(0)   { unhandledOptions[0]=0;alloptions[0]=0; };
+	explicit ProgramOptions(bool expectUnhandled_p = false) : expectUnhandled(expectUnhandled_p), unhandledCounter(0), optcount(0)   { unhandledOptions[0]=0;alloptions[0]=0; };
 
 	virtual ~ProgramOptions() {}
 	unsigned int parseoptions(ostream & outstr, unsigned int argc, const char * const*argv) ;
 	// unsigned int sheet: -1 indicates "all"
 	void showhelp(ostream & outstr, bool forTeX, bool withdescription, int sheet = -1) const ;
 	void dumpunhandled(ostream & outstr) const ;	
+#if 1
 	void showvalues(ostream & outstr, bool withdescription = true) const ;
+#endif
 	const OptionBase * const * getOptionConstIterator() const { return &alloptions[0]; }
 	OptionBase * const * getOptionIterator() const { return &alloptions[0]; }
 	unsigned int numberOfOptions() const { return optcount; }
@@ -209,6 +216,7 @@ public:
 	void add(OptionBase * op, const char * const membername) ;
 
   public:
+	bool expectUnhandled; // whether to expect unhandled arguments
 	unsigned int unhandledCounter;
 	const char *unhandledOptions[100];
 
@@ -222,4 +230,3 @@ public:
 };
 
 #endif
- 
